#[repr(u8)]pub enum CodecType {
Bitpacked = 0,
Linear = 1,
BlockwiseLinear = 2,
}Expand description
Available codecs to use to encode the u64 (via MonotonicallyMappableToU64) converted data.
Variants
Bitpacked = 0
Bitpack all values in the value range. The number of bits is defined by the amplitude
column.max_value() - column.min_value()
Linear = 1
Linear interpolation puts a line between the first and last value and then bitpacks the values by the offset from the line. The number of bits is defined by the max deviation from the line.
BlockwiseLinear = 2
Same as CodecType::Linear, but encodes in blocks of 512 elements.
Implementations